@@ -25,6 +25,8 @@
 #include <arpa/inet.h>
 #include <libxml/parser.h>
 #include <libxml/tree.h>
+#include <dirent.h>
+#include <vorbis/vorbisfile.h>
 #include "garagejam.h"
 #include "garagejam-gingerblue-chord.h"
 #include "garagejam-gingerblue-config.h"
@@ -80,6 +82,63 @@ gchar xspfbuffer[8192];
 
 GError *error = NULL;
 
+#define MAX_PATH_LENGTH 1024
+
+void write_xspf_header(FILE *file) {
+    fprintf(file, "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
+    fprintf(file, "<playlist version=\"1\" xmlns=\"http://xspf.org/ns/0/\">\n");
+    fprintf(file, "  <title>GNOME Playlist</title>\n");
+    fprintf(file, "  <trackList>\n");
+}
+
+void write_xspf_track(FILE *file, const char *title, const char *artist, const char *album, const char *location) {
+    fprintf(file, "    <track>\n");
+    fprintf(file, "      <title>%s</title>\n", title);
+    fprintf(file, "      <creator>%s</creator>\n", artist);
+    fprintf(file, "      <album>%s</album>\n", album);
+    fprintf(file, "      <location>%s</location>\n", location);
+    fprintf(file, "    </track>\n");
+}
+
+void write_xspf_footer(FILE *file) {
+    fprintf(file, "  </trackList>\n");
+    fprintf(file, "</playlist>\n");
+}
+
+void process_ogg_file(const char *filename, FILE *xspf_file) {
+    OggVorbis_File vf;
+    if (ov_fopen(filename, &vf) != 0) {
+        fprintf(stderr, "Error opening file: %s\n", filename);
+        return;
+    }
+
+    vorbis_info *info = ov_info(&vf, -1);
+
+    char title[MAX_PATH_LENGTH];
+    char artist[MAX_PATH_LENGTH];
+    char album[MAX_PATH_LENGTH];
+    strncpy(title, filename, sizeof(title));
+    strncpy(artist, gtk_entry_get_text(GTK_ENTRY(musician_entry)), sizeof(artist));
+    strncpy(album, gtk_entry_get_text(GTK_ENTRY(album_entry)), sizeof(album));
+
+    vorbis_comment *vc = ov_comment(&vf, -1);
+    for (int i = 0; i < vc->comments; i++) {
+        if (strstr(vc->user_comments[i], "TITLE=") == vc->user_comments[i]) {
+            strncpy(title, vc->user_comments[i] + 6, sizeof(title));
+        }
+        if (strstr(vc->user_comments[i], "ARTIST=") == vc->user_comments[i]) {
+            strncpy(artist, vc->user_comments[i] + 7, sizeof(artist));
+        }
+        if (strstr(vc->user_comments[i], "ALBUM=") == vc->user_comments[i]) {
+            strncpy(album, vc->user_comments[i] + 6, sizeof(album));
+        }
+    }
+
+    write_xspf_track(xspf_file, title, artist, album, filename);
+
+    ov_clear(&vf);
+}
+
 // Signal handler for playlist entry selection
 void on_playlist_entry_selected(GtkListBox *listbox, GtkListBoxRow *row,
 				gpointer user_data)
@@ -243,7 +302,7 @@ static void gb_assistant_button_clicked(GtkButton *button,
 				GST_TAG_TITLE, g_get_real_name(),
 				GST_TAG_ARTIST, g_get_real_name(),
 				GST_TAG_ALBUM, "Voicegram",
-				GST_TAG_COMMENT, "GNOME 43",
+				GST_TAG_COMMENT, "GNOME 45",
 				GST_TAG_DATE,
 				g_date_time_format_iso8601(datestamp),
 				NULL);
@@ -306,8 +365,8 @@ static void gb_assistant_close(GtkAssistant *assistant, gpointer data)
 	fprintf(fp, "</gingerblue>\n");
 	fclose(fp);
 	g_date_time_unref(datestamp);
-	main_studio_stream(filename,
-			   gtk_entry_get_text(GTK_ENTRY(studio_entry)));
+	/* main_studio_stream(filename, */
+	/* 		   gtk_entry_get_text(GTK_ENTRY(studio_entry))); */
 	gst_element_send_event(data, gst_event_new_eos());
 }
 
@@ -344,6 +403,7 @@ void free_playlist_entry(gpointer data)
 	}
 }
 
+
 int main(int argc, char **argv)
 {
 	GSocketConnectable *addr;
@@ -701,18 +761,6 @@ int main(int argc, char **argv)
 
 	gst_element_set_state(pipeline, GST_STATE_PLAYING);
 
-	xspf =
-	    fopen(g_strconcat
-		  (g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
-		   gtk_entry_get_text(GTK_ENTRY(label_entry)), ".xspf",
-		   NULL), "w+");
-	sprintf(xspfbuffer,
-		"<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<playlist version=\"1\" xmlns=\"http://xspf.org/ns/0/\">\n<trackList>\n<track>\n<title>%s</title>\n<location>file://%s</location>\n</track>\n</trackList>\n</playlist>\n",
-		gtk_entry_get_text(GTK_ENTRY(song_entry)),
-		gtk_entry_get_text(GTK_ENTRY(recording_entry)));
-	fprintf(xspf, "%s", xspfbuffer);
-	fclose(xspf);
-
 	gtk_widget_set_size_request(GTK_WIDGET(window), 800, 600);
 	gtk_window_set_title(GTK_WINDOW(window),
 			     g_strconcat(g_get_user_special_dir
@@ -724,24 +772,64 @@ int main(int argc, char **argv)
 	list = gtk_list_box_new();
 	gtk_container_add(GTK_CONTAINER(window), list);
 
-	// Get the user's music directory
-	gchar *music_dir =
-	    g_strdup_printf("%s",
-			    g_get_user_special_dir
-			    (G_USER_DIRECTORY_MUSIC));
-	gchar *playlist_file =
-	    g_build_filename(music_dir, "GNOME.xspf", NULL);
+	    const char *ogg_dir = g_strdup_printf("%s",
+						  g_get_user_special_dir
+						  (G_USER_DIRECTORY_MUSIC));
+	    
+	    if (ogg_dir == NULL) {
+	      fprintf(stderr, "Error getting G_USER_DIRECTORY_MUSIC variable.\n");
+	      return 1;
+	    }
 
-	// Parse the playlist file
-	parse_xspf_file(playlist_file, &playlist_entries);
+    char xspf_path[MAX_PATH_LENGTH];
+    snprintf(xspf_path, sizeof(xspf_path), "%s/GNOME.xspf", ogg_dir);
 
-	// Add playlist entries to the list
-	// Add playlist entries to the list
-	GList *iter;
-	for (iter = playlist_entries; iter != NULL;
-	     iter = g_list_next(iter)) {
-		PlaylistEntry *entry = (PlaylistEntry *) iter->data;
-		GtkWidget *label = gtk_label_new(entry->title);
+    FILE *xspf_file = fopen(xspf_path, "w");
+    if (xspf_file == NULL) {
+        fprintf(stderr, "Error opening XSPF file for writing.\n");
+        return 1;
+    }
+
+    write_xspf_header(xspf_file);
+
+    DIR *dir;
+    struct dirent *ent;
+    if ((dir = opendir(ogg_dir)) != NULL) {
+        while ((ent = readdir(dir)) != NULL) {
+            if (ent->d_type == DT_REG && strstr(ent->d_name, ".ogg") != NULL) {
+                char file_path[MAX_PATH_LENGTH];
+                snprintf(file_path, sizeof(file_path), "%s/%s", ogg_dir, ent->d_name);
+                process_ogg_file(file_path, xspf_file);
+            }
+        }
+        closedir(dir);
+    } else {
+        fprintf(stderr, "Error opening directory.\n");
+        return 1;
+    }
+
+    write_xspf_footer(xspf_file);
+
+    fclose(xspf_file);
+
+    // Get the user's music directory
+    gchar *music_dir =
+      g_strdup_printf("%s",
+		      g_get_user_special_dir
+		      (G_USER_DIRECTORY_MUSIC));
+    gchar *playlist_file =
+      g_build_filename(music_dir, "GNOME.xspf", NULL);
+    
+    // Parse the playlist file
+    parse_xspf_file(playlist_file, &playlist_entries);
+    
+    // Add playlist entries to the list
+    // Add playlist entries to the list
+    GList *iter;
+    for (iter = playlist_entries; iter != NULL;
+	 iter = g_list_next(iter)) {
+      PlaylistEntry *entry = (PlaylistEntry *) iter->data;
+      GtkWidget *label = gtk_label_new(entry->title);
 		// Create a list box row
 		GtkListBoxRow *row =
 		    GTK_LIST_BOX_ROW(gtk_list_box_row_new());
